API Documentation — Meta Package Manager 2.4.1 documentation

# API Documentation

- `meta_package_manager.base` - Package manager definition
- `meta_package_manager.managers` - Managers implementation
  - `meta_package_manager.managers.apm`
  - `meta_package_manager.managers.gem`
  - `meta_package_manager.managers.homebrew`
  - `meta_package_manager.managers.mas`
  - `meta_package_manager.managers.npm`
  - `meta_package_manager.managers.pip`
- `meta_package_manager.platform`
- `meta_package_manager.cli` - mpm CLI
- `meta_package_manager.bitbar` - BitBar plugin

## Module contents

Expose package-wide elements.

`meta_package_manager.` `__version__`